==> huaweicloudsdkgaussdb-3.0.64-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/expand_gauss_my_sql_instance_volume_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandGaussMySqlInstanceVolumeResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'size': 'int',
        'order_id': 'str'
    }

    attribute_map = {
        'size': 'size',
        'order_id': 'order_id'
    }

    def __init__(self, size=None, order_id=None):
        """ExpandGaussMySqlInstanceVolumeResponse - a model defined in huaweicloud sdk"""
        
        super(ExpandGaussMySqlInstanceVolumeResponse, self).__init__()

        self._size = None
        self._order_id = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if order_id is not None:
            self.order_id = order_id

    @property
    def size(self):
        """Gets the size of this ExpandGaussMySqlInstanceVolumeResponse.

        扩容后容量。

        :return: The size of this ExpandGaussMySqlInstanceVolumeResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ExpandGaussMySqlInstanceVolumeResponse.

        扩容后容量。

        :param size: The size of this ExpandGaussMySqlInstanceVolumeResponse.
        :type: int
        """
        self._size = size

    @property
    def order_id(self):
        """Gets the order_id of this ExpandGaussMySqlInstanceVolumeResponse.

        订单号。

        :return: The order_id of this ExpandGaussMySqlInstanceVolumeResponse.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ExpandGaussMySqlInstanceVolumeResponse.

        订单号。

        :param order_id: The order_id of this ExpandGaussMySqlInstanceVolumeResponse.
        :type: str
        """
        self._order_id = order_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandGaussMySqlInstanceVolumeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgaussdb-3.0.102-py2.py3-none-any.whl: huaweicloudsdkgaussdb/v3/model/expand_gauss_my_sql_instance_volume_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExpandGaussMySqlInstanceVolumeResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'size': 'int',
        'order_id': 'str'
    }

    attribute_map = {
        'size': 'size',
        'order_id': 'order_id'
    }

    def __init__(self, size=None, order_id=None):
        """ExpandGaussMySqlInstanceVolumeResponse

        The model defined in huaweicloud sdk

        :param size: 扩容后容量。
        :type size: int
        :param order_id: 订单号。
        :type order_id: str
        """
        
        super(ExpandGaussMySqlInstanceVolumeResponse, self).__init__()

        self._size = None
        self._order_id = None
        self.discriminator = None

        if size is not None:
            self.size = size
        if order_id is not None:
            self.order_id = order_id

    @property
    def size(self):
        """Gets the size of this ExpandGaussMySqlInstanceVolumeResponse.

        扩容后容量。

        :return: The size of this ExpandGaussMySqlInstanceVolumeResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ExpandGaussMySqlInstanceVolumeResponse.

        扩容后容量。

        :param size: The size of this ExpandGaussMySqlInstanceVolumeResponse.
        :type size: int
        """
        self._size = size

    @property
    def order_id(self):
        """Gets the order_id of this ExpandGaussMySqlInstanceVolumeResponse.

        订单号。

        :return: The order_id of this ExpandGaussMySqlInstanceVolumeResponse.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this ExpandGaussMySqlInstanceVolumeResponse.

        订单号。

        :param order_id: The order_id of this ExpandGaussMySqlInstanceVolumeResponse.
        :type order_id: str
        """
        self._order_id = order_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExpandGaussMySqlInstanceVolumeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
